@@ -9,15 +9,15 @@
 #  ifndef LEATHERMAN_CURL_EXPORT
 #    ifdef leatherman_curl_EXPORTS
         /* We are building this library */
-#      define LEATHERMAN_CURL_EXPORT 
+#      define LEATHERMAN_CURL_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define LEATHERMAN_CURL_EXPORT 
+#      define LEATHERMAN_CURL_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef LEATHERMAN_CURL_NO_EXPORT
-#    define LEATHERMAN_CURL_NO_EXPORT 
+#    define LEATHERMAN_CURL_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
@@ -39,4 +39,4 @@
 #  endif
 #endif
 
-#endif
+#endif /* LEATHERMAN_CURL_EXPORT_H */
